<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="bg">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation type="unfinished">Нов отбор</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Edit schemes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit weapons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation>Невалидна оръжейна схема</translation>
    </message>
    <message>
        <source>When this option is enabled selecting a game scheme will auto-select a weapon</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Добре</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>Грешка при запис във файл %1</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation>Грешка при стартиране на сървъра</translation>
    </message>
    <message>
        <source>new</source>
        <translation type="obsolete">Нов отбор</translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>Изберете запис от списъка</translation>
    </message>
    <message>
        <source>DefaultTeam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars Demo File</source>
        <comment>File Types</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars Save File</source>
        <comment>File Types</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>bg.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation>Не може да се отвори демо файл %1</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>Карта</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Тема</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Филтър</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Всички</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Малка</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Средна</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Голяма</translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation>Пещера</translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation>Щура</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>Име</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation>Грешка при свързване. Моля проверете името на сървъра и порта.</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>Отказано свързване</translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation>Причина за напускане:</translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation>Стаята бе унищожена</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password below
or pick another nickname in game config:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation>SDL_ttf се натъкна на грешка при показването на текста, най-вероятно свързана с програмна грешка в библиотеката freetype2. Препоръчително е да я обновите.</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Clear Accounts Cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageDrawMap</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load</source>
        <translation type="unfinished">Зареждане</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load drawn map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drawn Maps (*.hwmap);;All files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save drawn map</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation>Общи</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>За напреднали</translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;Награда за най-добър изстрел е спечелена от &lt;b&gt;%1&lt;/b&gt; с &lt;b&gt;%2&lt;/b&gt; точки.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Health graph</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ranking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%1 kill)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; thought it&apos;s good to shoot his own hedgehogs with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; killed &lt;b&gt;%2&lt;/b&gt; of his own hedgehogs.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; was scared and skipped turn &lt;b&gt;%2&lt;/b&gt; times.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation>Локална игра (играйте на един компютър)</translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation>Мрежова игра (играйте в мрежа)</translation>
    </message>
    <message>
        <source>Simply pick the same color as a friend to play together as a team. Each of you will still control his or her own hedgehogs but they&apos;ll win or lose together.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Some weapons might do only low damage but they can be a lot more devastating in the right situation. Try to use the Desert Eagle to knock multiple hedgehogs into the water.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you&apos;re unsure what to do and don&apos;t want to waste ammo, skip one round. But don&apos;t let too much time pass as there will be Sudden Death!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you&apos;d like to keep others from using your preferred nickname on the official server, register an account at http://www.hedgewars.org/.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You&apos;re bored of default gameplay? Try one of the missions - they&apos;ll offer different gameplay depending on the one you picked.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By default the game will always record the last game played as a demo. Select &apos;Local Game&apos; and pick the &apos;Demos&apos; button on the lower right corner to play or manage them.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you&apos;ve got problems, ask on our forums but please don&apos;t expect 24/7 support!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you like it, help us with a small donation or contribute your own work!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. Share it with your family and friends as you like!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>From time to time there will be official tournaments. Upcoming events will be announced at http://www.hedgewars.org/ some days in advance.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is available in many languages. If the translation in your language seems to be missing or outdated, feel free to contact us!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars can be run on lots of different operating systems including Microsoft Windows, Mac OS X and Linux.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always remember you&apos;re able to set up your own games in local and network/online play. You&apos;re not restricted to the &apos;Simple Game&apos; option.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>While playing you should give yourself a short break at least once an hour.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to enable the low quality mode to improve performance.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>We&apos;re open to suggestions and constructive feedback. If you don&apos;t like something or got a great idea, let us know!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Especially while playing online be polite and always remember there might be some minors playing with or against you as well!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Special game modes such as &apos;Vampirism&apos; or &apos;Karma&apos; allow you to develop completely new tactics. Try them in a custom game!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgwars to its game list so your friends can see you playing.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You should never install Hedgewars on computers you don&apos;t own (school, university, work, etc.). Please ask the responsible person instead!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars can be perfect for short games during breaks. Just ensure you don&apos;t add too many hedgehogs or use an huge map. Reducing time and health might help as well.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No hedgehogs were harmed in making this game.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If someone sold you the game, you should try get a refund!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect one or more gamepads before starting the game to be able to assign their controls to your teams.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create an account on %1 to keep others from using your most favourite nickname while playing on the official server.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to update the associated drivers.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There are three different jumps available. Tap [high jump] twice to do a very high/backwards jump.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Afraid of falling off a cliff? Hold down [precise] to turn [left] or [right] without actually moving.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Some weapons require special strategies or just lots of training, so don&apos;t give up on a particular tool if you miss an enemy once.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Most weapons won&apos;t work once they touch the water. The Homing Bee as well as the Cake are exceptions to this.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Old Limbuger only causes a small explosion. However the wind affected smelly cloud can poison lots of hogs at once.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Piano Strike is the most damaging air strike. You&apos;ll lose the hedgehog performing it, so there&apos;s a huge downside as well.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Homing Bee can be tricky to use. It&apos;s turn radius depends on it&apos;s velocity, so try to not use full power.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sticky Mines are a perfect tool to create small chain reactions knocking enemy hedgehogs into dire situations ... or water.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Hammer is most effective when used on bridges or girders. Hit hogs will just break through the ground.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you&apos;re stuck behind an enemy hedgehog, use the Hammer to free yourself without getting damaged by an explosion.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Cake&apos;s maximum walking distance depends on the ground it has to pass. Use [attack] to detonate it early.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Flame Thrower is a weapon but it can be used for tunnel digging as well.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the Incinerating Grenade to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Want to know who&apos;s behind the game? Click on the Hedgewars logo in the main menu to see the credits.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Like Hedgewars? Become a fan on %1 or follow us on %2!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Feel free to draw your own graves, hats, flags or even maps and themes! But note that you&apos;ll have to share them somewhere to use them online.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Really want to wear a specific hat? Donate to us and receive an exclusive hat of your choice!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep your video card drivers up to date to avoid issues playing the game.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;My Documents\Hedgewars&quot;. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You&apos;re able to associate Hedgewars related files (savegames and demo recordings) with the game to launch them right from your favorite file or internet browser.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Want to save ropes? Release the rope in mid air and then shoot again. As long as you don&apos;t touch the ground you&apos;ll reuse your rope without wasting ammo!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;Library/Application Support/Hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;.hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>Изберете сървър от списъка</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Official server</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>Нов отбор</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>Редактиране на отбора</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can&apos;t edit teams from team selection. Go back to main menu to add, edit or delete teams.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New weapon set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit weapon set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete weapon set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>Преименуване</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>Въведете ново име на файл:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>Не може да се преименува в</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>Файлът не може да се изтрие</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>Изберете запис от списъка</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation>Създаване</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Присъединяване</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Опресняване</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>Моля въведете име на стая</translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation>Моля изберете стая от списъка</translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>State:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rules:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapons:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The game you are trying to join has started.
Do you still want to join the room?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Изтриване</translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AI respawns on death.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All (living) hedgehogs are fully restored at the end of turn</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Attacking does not end your turn.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapons are reset to starting values each turn.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Each hedgehog has its own ammo. It does not share with the team.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You will not have to worry about wind anymore.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wind will affect almost everything.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>По подразбиране</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Изтриване</translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation>Солова игра (бърза игра срещу компютър с готови настройки)</translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation>Мрежова игра (играйте срещу приятели или ИИ отбори)</translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation>Тренировка (упражнете уменията си в редица тренировъчни мисии). РАЗРАБОТВА СЕ</translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation>Демо (гледайте записани демота)</translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation>Зареди (заредете предишно запаметена игра)</translation>
    </message>
    <message>
        <source>Campaign Mode (...). IN DEVELOPMENT</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation>Изгони</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation>Ограничи присъединяване</translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation>Ограничи добавяне на отбори</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>Follow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Check for updates at startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable sound</source>
        <translation>Включване на звука</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Пълен екран</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>Показване на брой кадри за секунда</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>Показване на алтернативен режим на щетите</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation>Включване на музиката</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>Преден пълен екран</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation>Добави дата и час към името на записаното демо</translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation>Случайна карта...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>Човек</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Ниво</translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mission</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Community</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Any</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In lobby</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">По подразбиране</translation>
    </message>
    <message>
        <source>hand drawn map...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Game Modifiers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Team Members</source>
        <translation>Членове на отбора</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>Форт</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>Клавиши</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Отбори</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>Настройки на Звук/Графика</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>Играещи отбори</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>Мрежова игра</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="obsolete">Оръжия</translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Schemes and Weapons</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Game scheme</source>
        <translation type="unfinished">Игрови настройки</translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mines Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Net nick</source>
        <translation>Прякор</translation>
    </message>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation>Тази програма се разпространява под GNU (the GNU General Public License) лиценз</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Разделителна способност</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>Ограничение на брой кадри за секунда</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation>Разработчици:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>Графика:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>Преводи:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation>Специални благодарности на:</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation>Име на сървъра:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Сървър:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Оръжия</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>Звуци:</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation>Първоначална сила на звука</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Voice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Locale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tip: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This development build is &apos;work in progress&apos; and may not be compatible with other versions of the game. Some features might be broken or incomplete. Use at your own risk!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>% Health Crates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Health in Crates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sudden Death Water Rise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sudden Death Health Decrease</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>% Rope Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gameplay</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>Безименен</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation>Таралежови войни %1</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>Не може да се отвори папката с данните:
%1
Проверете инсталацията си</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Мрежа</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation>Загубена е връзката със сървъра</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Оръжия</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation type="obsolete">Не могат да се изтрият оръжията по подразбиране</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation>Да се изтрият ли тези оръжия?</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation type="obsolete">Не може да се редактират оръжията по подразбиране</translation>
    </message>
    <message>
        <source>Can not overwrite default weapon set &apos;%1&apos;!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All file associations have been set.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File association failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Teams</source>
        <translation type="unfinished">Отбори</translation>
    </message>
    <message>
        <source>Really delete this team?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Schemes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not delete default scheme &apos;%1&apos;!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Really delete this game scheme?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not delete default weapon set &apos;%1&apos;!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>Не може да се създаде папка %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>Setup</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>Пускане на демо</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Свързване</translation>
    </message>
    <message>
        <source>Go!</source>
        <translation>Напред!</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>Стартиране на сървъра</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Актуализиране</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Зареждане</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>Указване</translation>
    </message>
    <message>
        <source>default</source>
        <translation>По подразбиране</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Преименуване</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Изтриване</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Готово</translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Associate file extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>more</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Owner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Map</source>
        <translation type="unfinished">Карта</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="unfinished">Оръжия</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>new</source>
        <translation type="unfinished">Нов отбор</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>Грешка при стартиране на сървъра: %1.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>Грешка при пускане на engine-a: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Fort Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation type="unfinished">Добави гранична ивица</translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vampirism</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Karma</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>King</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AI Survival Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Health</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unlimited Attacks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Weapons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Per Hedgehog Ammo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More Wind</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>Нагоре</translation>
    </message>
    <message>
        <source>left</source>
        <translation>Наляво</translation>
    </message>
    <message>
        <source>right</source>
        <translation>Надясно</translation>
    </message>
    <message>
        <source>down</source>
        <translation>Надолу</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>Атака</translation>
    </message>
    <message>
        <source>put</source>
        <translation>Посочване</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>Превключване</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>Слот 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>Слот 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>Слот 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>Слот 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>Слот 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>Слот 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation>Слот 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation>Слот 8</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>Таймер 1 сек</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>Таймер 2 сек</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>Таймер 3 сек</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>Таймер 4 сек</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>Таймер 5 сек</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>Снимка</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>Изход</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>Намери таралежа</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>Меню с оръжия</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>Намаляване на звука</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>Усилване на звука</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>Смяна на режима</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>Слот 9</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>Информация
за играта</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>История на чата</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>Потвърждение</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation>Точен прицел</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>long jump</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>high jump</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>slot 10</source>
        <translation type="unfinished">Слот 10</translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Друго</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Изтриване</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Escape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Equals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LB button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RB button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DPad</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
